==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPivotGridColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridColumnDescription } from "./WebPivotGridColumnDescription";
/**
 * @hidden
 */
export let WebPivotGridColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotGridColumnDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotGridColumnDescriptionMetadata.a == null) {
                WebPivotGridColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotGridColumnDescriptionMetadata.c(WebPivotGridColumnDescriptionMetadata.a);
            }
            if (a.k(WebPivotGridColumnDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotGridColumnDescriptionMetadata.a);
            WebPivotDimensionDescriptionMetadata.d(a);
            WebPivotValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotGridColumn");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Field", "String");
            a.item("Dimensions", "Array:WebPivotDimensionDescription:PivotDimension");
            a.item("Value", "ExportedType:WebPivotValue");
        }
        static d(a) {
            WebPivotGridColumnDescriptionMetadata.b(a);
            a.ad("WebPivotGridColumn", () => new WebPivotGridColumnDescription());
            a.ac("WebPivotGridColumn", WebPivotGridColumnDescriptionMetadata.a);
        }
    }
    WebPivotGridColumnDescriptionMetadata.$t = markType(WebPivotGridColumnDescriptionMetadata, 'WebPivotGridColumnDescriptionMetadata');
    WebPivotGridColumnDescriptionMetadata.a = null;
    return WebPivotGridColumnDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPivotGridColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridColumnDescription } from "./WebPivotGridColumnDescription";
/**
 * @hidden
 */
export let WebPivotGridColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotGridColumnDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotGridColumnDescriptionMetadata.a == null) {
                WebPivotGridColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotGridColumnDescriptionMetadata.c(WebPivotGridColumnDescriptionMetadata.a);
            }
            if (a.k(WebPivotGridColumnDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotGridColumnDescriptionMetadata.a);
            WebPivotDimensionDescriptionMetadata.d(a);
            WebPivotValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotGridColumn");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Field", "String");
            a.item("Dimensions", "Array:WebPivotDimensionDescription:PivotDimension");
            a.item("Value", "ExportedType:WebPivotValue");
        }
        static d(a) {
            WebPivotGridColumnDescriptionMetadata.b(a);
            a.ae("WebPivotGridColumn", () => new WebPivotGridColumnDescription());
            a.ad("WebPivotGridColumn", WebPivotGridColumnDescriptionMetadata.a);
        }
    }
    WebPivotGridColumnDescriptionMetadata.$t = markType(WebPivotGridColumnDescriptionMetadata, 'WebPivotGridColumnDescriptionMetadata');
    WebPivotGridColumnDescriptionMetadata.a = null;
    return WebPivotGridColumnDescriptionMetadata;
})();
